@@ -16,6 +16,7 @@ from colorlog import escape_codes, default_log_colors
 
 import kipoi
 from kipoi.cli.env import conda_env_name, SPECIAL_ENV_PREFIX
+from kipoi.cli.singularity import singularity_command
 from kipoi_conda import get_kipoi_bin, env_exists, remove_env, _call_command
 from kipoi.sources import list_softlink_dependencies
 from kipoi_utils.utils import list_files_recursively, read_txt, get_file_path, cd
@@ -161,6 +162,15 @@ def test_model(model_name, source_name, env_name, batch_size,
         raise ValueError("{0} warnings were observed for model {1}".
                          format(warn, model_name))
 
+def test_model_singularity(model_name, source_name, batch_size, verbose=False):
+    """kipoi test ...
+
+    Args:
+      model_name (str)
+      source_name: source name
+    """
+    kipoi_cmd = ["kipoi", "test", f"{model_name}", f"--batch_size={batch_size}", "--source=kipoi"]
+    singularity_command(kipoi_cmd, model_name, {})
 
 def restrict_models_to_test(all_models, source, git_range):
     """Subset all_models to the ones with changed files
@@ -289,12 +299,19 @@ def cli_test_source(command, raw_args):
                         help="Shard id")
     parser.add_argument('--num_of_shards', type=int, default=-1,
                         help="Number of shards")
+    parser.add_argument('--singularity', action='store_true',
+                    help='Test models within their singularity containers')
+
 
     args = parser.parse_args(raw_args)
+    if args.singularity and args.source != "kipoi":
+        raise IOError("Singularity containers are available for kipoi models only")
+    if args.singularity and args.common_env:
+        raise IOError("Please use only one of --singularity and --common_env")
+
     # --------------------------------------------
     source = kipoi.get_source(args.source)
     all_models = all_models_to_test(source)
-
     if args.k is not None:
         all_models = [x for x in all_models if re.match(args.k, x)]
 
@@ -382,7 +399,7 @@ def cli_test_source(command, raw_args):
                                             m))
         print('-' * 20)
         try:
-            if not args.common_env:
+            if not args.common_env and not args.singularity:
                 # Prepend "test-" to the standard kipoi env name
                 env_name = conda_env_name(m, source=args.source)
                 env_name = "test-" + env_name
@@ -390,7 +407,12 @@ def cli_test_source(command, raw_args):
                 test_model(m, args.source, env_name,
                            get_batch_size(cfg, m, args.batch_size),
                            create_env=True, verbose=args.verbose)
-            else:
+            elif args.singularity and not args.common_env:
+                print("Testing within singularity container....")
+                test_model_singularity(m, args.source, 
+                           get_batch_size(cfg, m, args.batch_size),  
+                           verbose=args.verbose)
+            elif args.common_env and not args.singularity:
                 # figure out the common environment name
                 env_name = get_common_env(m, model_envs)
                 if env_name is None:
@@ -403,6 +425,8 @@ def cli_test_source(command, raw_args):
                 test_model(m, args.source, env_name,
                            get_batch_size(cfg, m, args.batch_size), 
                            create_env=False, verbose=args.verbose)
+            else:
+                raise IOError("Please either choose --common_env or --singularity or none")
         except Exception as e:
             logger.error("Model {0} failed: {1}".format(m, e))
             failed_models += [m]
