@@ -85,7 +85,6 @@ def get_model(model, source="kipoi", with_dataloader=True, **kwargs):
     - **name** (`str`): model name
     - **source** (`str`): model source
     - **source_dir** (`str`): local path to model source storage
-    - **postprocessing** (`dict`): dictionary of loaded plugin specifications
     - **writers** (dict): dictionary of arguments for writers
     - **pipeline** (`kipoi.pipeline.Pipeline`): handle to a `Pipeline` object
 
@@ -224,8 +223,6 @@ def get_model(model, source="kipoi", with_dataloader=True, **kwargs):
     mod.source = source
     mod.source_name = source_name
     mod.source_dir = source_dir
-    # parse the postprocessing module
-    mod.postprocessing = md.postprocessing
     mod.writers = md.writers
     if with_dataloader:
         mod.pipeline = Pipeline(model=mod, dataloader_cls=default_dataloader)
