@@ -164,7 +164,6 @@ def list_models_by_group(df, group_filter=""):
                                      for author in authors])),
             ("contributors", unique_list([contributor for contributors in x.contributors
                                           for contributor in contributors])),
-            ("veff_score_variants", x.veff_score_variants.any()),
             ("type", unique_list([t for t in x.type])),
             ("license", unique_list([l for l in x.license])),
             ("cite_as", unique_list([c for c in x.cite_as if c is not None])),
@@ -368,7 +367,6 @@ class Source(object):
                 ("inputs", to_namelist(d.schema.inputs)),
                 ("targets", to_namelist(d.schema.targets)),
                 ("license", d.info.license),
-                ("veff_score_variants", "variant_effects" in d.postprocessing),
                 ("cite_as", d.info.cite_as),
                 ("trained_on", d.info.trained_on),
                 ("training_procedure", d.info.training_procedure),
